@@ -60,6 +60,12 @@ namespace leatherman { namespace execution {
          * On Windows, create a new process group for the child process, but not a Job Object.
          */
         create_new_process_group = (1 << 8),
+        /**
+         * Inherit locale environment variables from the current process. Limited to LC_ALL and
+         * LOCALE, which are specifically overridden to "C" with merge_environment.
+         * Will not override those variables if explicitly passed in an environment map.
+         */
+        inherit_locale = (1 << 9),
         /**
          * A combination of all throw options.
          */
